@@ -1,12 +1,11 @@
 from dataclasses import dataclass
 
-from core.transform.Ignore import Ignore
-
 
 @dataclass
-class ExchangeTransform(Ignore):
+class ExchangeTransform:
     instrument: str
     transform: dict = None
+    ignore: bool = False
 
     def __eq__(self, other):
         return self.instrument == other.instrument
